==> blancoStringGroup-0.1.1-src.zip: blancoStringGroup/blanco.php/main/blanco/sample/stringgroup/SampleStringGroup.php <==
<?php
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
/*. DOC <@package blanco.sample.stringgroup;>.*/

/*. require_module 'standard'; .*/;

/**
 * O[ṽTvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B
 */
class SampleStringGroup {
    /**
     * No.1 :At@xbg̕`B
     */
    const ABCDEFG = 1;

    /**
     * No.2 :Sp̕`B
     */
    const AIUEO = 2;

    /**
     * No.3 :VONI[gWJ邱Ƃ̊mFB
     */
    const QUOTE = 3;

    /**
     * No.4 :_uNI[gWJ邱Ƃ̊mFB
     */
    const DOUBLE_QUOTE = 4;

    /**
     * No.5 :obNXbVWJ邱Ƃ̊mFB
     */
    const BACK_SLASH = 5;

    /**
     * No.7
     */
    const WITHOUT_DESC = 7;

    /**
     * No.8 :r̋󔒂K؂ɏ邱Ƃ̊mFB
     */
    const TEST_SPACE = 8;

    /**
     * `BO[vȊO̕܂͒萔`̂́B
     */
    const NOT_DEFINED = -1;

    /**
     * O[vɊ܂܂镶ł邩ǂ𔻒肵܂B
     *
     * @param argCheck `FbNsB
     * @return O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB
     */
    public /*.boolean.*/ function match(/*.string.*/ $argCheck) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 1) {
            throw new Exception('[ArgumentException]: SampleStringGroup.match ̃p[^[1]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($argCheck) !== 'string') {
            throw new Exception('[ArgumentException]: SampleStringGroup.match 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($argCheck) . ']^^܂B');
        }

        // No.1
        // :At@xbg̕`B
        if ('ABCDEFG' === $argCheck) {
            return true;
        }
        // No.2
        // :Sp̕`B
        if ('' === $argCheck) {
            return true;
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if ('\'' === $argCheck) {
            return true;
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if ('"' === $argCheck) {
            return true;
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if ('\\' === $argCheck) {
            return true;
        }
        // No.6
        // :萔ȗꂽ`B
        if ('STRING ONLY' === $argCheck) {
            return true;
        }
        // No.7
        if ('ȗ' === $argCheck) {
            return true;
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if ('ABC DEF' === $argCheck) {
            return true;
        }
        return false;
    }

    /**
     * O[vɊ܂܂镶ł邩ǂA啶ʂ肵܂B
     *
     * @param argCheck `FbNsB
     * @return O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB
     */
    public /*.boolean.*/ function matchIgnoreCase(/*.string.*/ $argCheck) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 1) {
            throw new Exception('[ArgumentException]: SampleStringGroup.matchIgnoreCase ̃p[^[1]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($argCheck) !== 'string') {
            throw new Exception('[ArgumentException]: SampleStringGroup.matchIgnoreCase 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($argCheck) . ']^^܂B');
        }

        // No.1
        // :At@xbg̕`B
        if (strtoupper('ABCDEFG') === strtoupper($argCheck)) {
            return true;
        }
        // No.2
        // :Sp̕`B
        if (strtoupper('') === strtoupper($argCheck)) {
            return true;
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if (strtoupper('\'') === strtoupper($argCheck)) {
            return true;
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if (strtoupper('"') === strtoupper($argCheck)) {
            return true;
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if (strtoupper('\\') === strtoupper($argCheck)) {
            return true;
        }
        // No.6
        // :萔ȗꂽ`B
        if (strtoupper('STRING ONLY') === strtoupper($argCheck)) {
            return true;
        }
        // No.7
        if (strtoupper('ȗ') === strtoupper($argCheck)) {
            return true;
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if (strtoupper('ABC DEF') === strtoupper($argCheck)) {
            return true;
        }
        return false;
    }

    /**
     * 񂩂萔ɕϊ܂B
     *
     * 萔`̏ꍇ ^ꂽ񂪕O[vȌꍇɂ NOT_DEFINED ߂܂B
     *
     * @param argCheck ϊsB
     * @return 萔ɕϊ̒lB
     */
    public /*.int.*/ function convertToInt(/*.string.*/ $argCheck) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 1) {
            throw new Exception('[ArgumentException]: SampleStringGroup.convertToInt ̃p[^[1]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($argCheck) !== 'string') {
            throw new Exception('[ArgumentException]: SampleStringGroup.convertToInt 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($argCheck) . ']^^܂B');
        }

        // No.1
        // :At@xbg̕`B
        if ('ABCDEFG' === $argCheck) {
            return self::ABCDEFG;
        }
        // No.2
        // :Sp̕`B
        if ('' === $argCheck) {
            return self::AIUEO;
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if ('\'' === $argCheck) {
            return self::QUOTE;
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if ('"' === $argCheck) {
            return self::DOUBLE_QUOTE;
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if ('\\' === $argCheck) {
            return self::BACK_SLASH;
        }
        // No.7
        if ('ȗ' === $argCheck) {
            return self::WITHOUT_DESC;
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if ('ABC DEF' === $argCheck) {
            return self::TEST_SPACE;
        }

        // Y萔܂łB
        return self::NOT_DEFINED;
    }
}
?>

==> blancoStringGroup-0.1.5-src.zip: blancoStringGroup/blanco.php/main/blanco/sample/stringgroup/SampleStringGroup.php <==
<?php
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
/*. DOC <@package blanco.sample.stringgroup;>.*/

/*. require_module 'standard'; .*/;

/**
 * O[ṽTvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B
 */
class SampleStringGroup {
    /**
     * No.1 :At@xbg̕`B
     */
    const ABCDEFG = 1;

    /**
     * No.2 :Sp̕`B
     */
    const AIUEO = 2;

    /**
     * No.3 :VONI[gWJ邱Ƃ̊mFB
     */
    const QUOTE = 3;

    /**
     * No.4 :_uNI[gWJ邱Ƃ̊mFB
     */
    const DOUBLE_QUOTE = 4;

    /**
     * No.5 :obNXbVWJ邱Ƃ̊mFB
     */
    const BACK_SLASH = 5;

    /**
     * No.7
     */
    const WITHOUT_DESC = 7;

    /**
     * No.8 :r̋󔒂K؂ɏ邱Ƃ̊mFB
     */
    const TEST_SPACE = 8;

    /**
     * No.9 :~}[NB
     */
    const BATU = 9;

    /**
     * `BO[vȊO̕܂͒萔`̂́B
     */
    const NOT_DEFINED = -1;

    /**
     * O[vɊ܂܂镶ł邩ǂ𔻒肵܂B
     *
     * @param string $argCheck `FbNsB
     * @return boolean O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB
     */
    public /*.boolean.*/ function match(/*.string.*/ $argCheck) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 1) {
            throw new Exception('[ArgumentException]: SampleStringGroup.match ̃p[^[1]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($argCheck) !== 'string' && gettype($argCheck) !== 'NULL') {
            throw new Exception('[ArgumentException]: SampleStringGroup.match 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($argCheck) . ']^^܂B');
        }

        // No.1
        // :At@xbg̕`B
        if ('ABCDEFG' === $argCheck) {
            return true;
        }
        // No.2
        // :Sp̕`B
        if ('' === $argCheck) {
            return true;
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if ('\'' === $argCheck) {
            return true;
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if ('"' === $argCheck) {
            return true;
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if ('\\' === $argCheck) {
            return true;
        }
        // No.6
        // :萔ȗꂽ`B
        if ('STRING ONLY' === $argCheck) {
            return true;
        }
        // No.7
        if ('ȗ' === $argCheck) {
            return true;
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if ('ABC DEF' === $argCheck) {
            return true;
        }
        // No.9
        // :~}[NB
        if ('~' === $argCheck) {
            return true;
        }
        return false;
    }

    /**
     * O[vɊ܂܂镶ł邩ǂA啶ʂ肵܂B
     *
     * @param string $argCheck `FbNsB
     * @return boolean O[vɊ܂܂ĂtureBO[vɊ܂܂ȂłfalseB
     */
    public /*.boolean.*/ function matchIgnoreCase(/*.string.*/ $argCheck) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 1) {
            throw new Exception('[ArgumentException]: SampleStringGroup.matchIgnoreCase ̃p[^[1]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($argCheck) !== 'string' && gettype($argCheck) !== 'NULL') {
            throw new Exception('[ArgumentException]: SampleStringGroup.matchIgnoreCase 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($argCheck) . ']^^܂B');
        }

        // No.1
        // :At@xbg̕`B
        if (strtoupper('ABCDEFG') === strtoupper($argCheck)) {
            return true;
        }
        // No.2
        // :Sp̕`B
        if (strtoupper('') === strtoupper($argCheck)) {
            return true;
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if (strtoupper('\'') === strtoupper($argCheck)) {
            return true;
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if (strtoupper('"') === strtoupper($argCheck)) {
            return true;
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if (strtoupper('\\') === strtoupper($argCheck)) {
            return true;
        }
        // No.6
        // :萔ȗꂽ`B
        if (strtoupper('STRING ONLY') === strtoupper($argCheck)) {
            return true;
        }
        // No.7
        if (strtoupper('ȗ') === strtoupper($argCheck)) {
            return true;
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if (strtoupper('ABC DEF') === strtoupper($argCheck)) {
            return true;
        }
        // No.9
        // :~}[NB
        if (strtoupper('~') === strtoupper($argCheck)) {
            return true;
        }
        return false;
    }

    /**
     * 񂩂萔ɕϊ܂B
     *
     * 萔`̏ꍇ ^ꂽ񂪕O[vȌꍇɂ NOT_DEFINED ߂܂B
     *
     * @param string $argCheck ϊsB
     * @return integer 萔ɕϊ̒lB
     */
    public /*.int.*/ function convertToInt(/*.string.*/ $argCheck) {
        /* p[^̐A^`FbNs܂B */
        if (func_num_args() !== 1) {
            throw new Exception('[ArgumentException]: SampleStringGroup.convertToInt ̃p[^[1]łKv܂Bۂɂ[' . func_num_args() .  ']̃p[^𔺂ČĂяo܂B');
        }
        if (gettype($argCheck) !== 'string' && gettype($argCheck) !== 'NULL') {
            throw new Exception('[ArgumentException]: SampleStringGroup.convertToInt 1Ԗڂ̃p[^[string]^łȂĂ͂Ȃ܂Bۂɂ[' . gettype($argCheck) . ']^^܂B');
        }

        // No.1
        // :At@xbg̕`B
        if ('ABCDEFG' === $argCheck) {
            return self::ABCDEFG;
        }
        // No.2
        // :Sp̕`B
        if ('' === $argCheck) {
            return self::AIUEO;
        }
        // No.3
        // :VONI[gWJ邱Ƃ̊mFB
        if ('\'' === $argCheck) {
            return self::QUOTE;
        }
        // No.4
        // :_uNI[gWJ邱Ƃ̊mFB
        if ('"' === $argCheck) {
            return self::DOUBLE_QUOTE;
        }
        // No.5
        // :obNXbVWJ邱Ƃ̊mFB
        if ('\\' === $argCheck) {
            return self::BACK_SLASH;
        }
        // No.7
        if ('ȗ' === $argCheck) {
            return self::WITHOUT_DESC;
        }
        // No.8
        // :r̋󔒂K؂ɏ邱Ƃ̊mFB
        if ('ABC DEF' === $argCheck) {
            return self::TEST_SPACE;
        }
        // No.9
        // :~}[NB
        if ('~' === $argCheck) {
            return self::BATU;
        }

        // Y萔܂łB
        return self::NOT_DEFINED;
    }
}
?>
